==> server-core-3.6.3-sources.jar: com/xebialabs/deployit/jcr/JcrConstants.java <==
package com.xebialabs.deployit.jcr;

import com.xebialabs.deployit.task.Task;

/**
 * 
 */
public interface JcrConstants {

	/**
	 * Username that represents the anonymous user.
	 */
	public static final String ANONYMOUS_USERNAME = "anonymous";

	/**
	 * Default username for administrative user in Jackrabbit
	 */
	public static final String ADMIN_USERNAME = "admin";

	/**
	 * Default password for administrative user in Jackrabbit
	 */
	public static final String ADMIN_PASSWORD = "admin";

	/**
	 * JCR namespace prefix for Deployit specific types and properties
	 */
	public static final String DEPLOYIT_NAMESPACE_PREFIX = "deployit";

	/**
	 * JCR namespace URI for Deployit specific types and properties
	 */
	public static final String DEPLOYIT_NAMESPACE_URI = "http://www.xebialabs.com/deployit";

	/**
	 * Prefix for JCR property names that are used to store Deployit metadata.
	 */
	public static final String METADATA_PROPERTY_NAME_PREFIX = "$";

	/**
	 * JCR node type name for {@link com.xebialabs.deployit.plugin.api.udm.ConfigurationItem configuration items}.
	 */
	public static final String CONFIGURATION_ITEM_NODETYPE_NAME = DEPLOYIT_NAMESPACE_PREFIX + ":configurationItem";

	/**
	 * JCR node type name for {@link com.xebialabs.deployit.plugin.api.udm.artifact.Artifact artifacts}.
	 */
	public static final String ARTIFACT_NODETYPE_NAME = DEPLOYIT_NAMESPACE_PREFIX + ":artifact";

	/**
	 * Name of property used to store the {@link com.xebialabs.deployit.plugin.api.udm.ConfigurationItem#getId() configuration item id}.
	 */
	public static final String ID_PROPERTY_NAME = METADATA_PROPERTY_NAME_PREFIX + "id";

	/**
	 * Name of property used to store the last modification date.
	 */
	public static final String LAST_MODIFIED_DATE_PROPERTY_NAME = METADATA_PROPERTY_NAME_PREFIX + "lastModified";

	/**
	 * Name of property used to store the creating task id
	 */
	public static final String CREATING_TASK_ID_PROPERTY_NAME = METADATA_PROPERTY_NAME_PREFIX + "creatingTaskId";

	/**
	 * Name of property used to store the {@link com.xebialabs.deployit.plugin.api.udm.ConfigurationItem#getType() configuration item type name}
	 */
	public static final String CONFIGURATION_ITEM_TYPE_PROPERTY_NAME = METADATA_PROPERTY_NAME_PREFIX + "configuration.item.type";

	/**
	 * Name of property used to store the {@link com.xebialabs.deployit.plugin.api.udm.artifact.Artifact#getFile() artifact filename}.
	 */
	public static final String FILENAME_PROPERTY_NAME = METADATA_PROPERTY_NAME_PREFIX + "filename";

	/**
	 * Name of property used to store the {@link com.xebialabs.deployit.plugin.api.udm.artifact.Artifact#getFile() artifact data}.
	 */
	public static final String DATA_PROPERTY_NAME = METADATA_PROPERTY_NAME_PREFIX + "data";

	/**
	 * JCR node type name for {@link Task tasks}.
	 */
	public static final String TASK_NODETYPE_NAME = DEPLOYIT_NAMESPACE_PREFIX + ":task";

	/**
	 * Name of JCR node under which tasks are stored.
	 */
	public static final String TASKS_NODE_NAME = "tasks";

	/**
	 * Full path of JCR node under which tasks are stored.
	 */
	public static final String TASKS_NODE_ID = "/" + TASKS_NODE_NAME;

	/**
	 * JCR node type name for {@link com.xebialabs.deployit.task.TaskStep steps}.
	 */
	public static final String STEP_NODETYPE_NAME = DEPLOYIT_NAMESPACE_PREFIX + ":step";

	/**
	 * Prefix used for the name of nodes that store steps.
	 */
	public static final String STEP_NODE_NAME_PREFIX = "step";

	/**
	 * JCR node type name used to store the configuration
	 */
	public static final String CONFIGURATION_NODETYPE_NAME = DEPLOYIT_NAMESPACE_PREFIX + ":configuration";

	/**
	 * Name of JCR node used to store the configuration
	 */
	public static final String CONFIGURATION_NODE_NAME = "$configuration";

	/**
	 * Full path of JCR node used to store the configuration
	 */
	public static final String CONFIGURATION_NODE_ID = "/" + CONFIGURATION_NODE_NAME;

    /**
     * Name of JCR node used to store the version information.
     */
    public static final String VERSIONS_NODE_NAME = CONFIGURATION_NODE_NAME + "/versions";

    /**
     * Full path of the JCR node used to store all version information under.
     */
    public static final String VERSIONS_NODE_ID = "/" + VERSIONS_NODE_NAME;

	/**
	 * Name of JCR node used to store security permissions under.
	 */
	public static final String SECURITY_NODE_NAME = CONFIGURATION_NODE_NAME + "/security";

	/**
	 * Full path of the JCR node used to store security permissions under.
	 */
	public static final String SECURITY_NODE_ID = "/" + SECURITY_NODE_NAME;
}

==> server-core-3.7.3-sources.jar: com/xebialabs/deployit/jcr/JcrConstants.java <==
package com.xebialabs.deployit.jcr;

import com.xebialabs.deployit.task.Task;

/**
 * 
 */
public interface JcrConstants {

	/**
	 * Username that represents the anonymous user.
	 */
	public static final String ANONYMOUS_USERNAME = "anonymous";

	/**
	 * Default username for administrative user in Jackrabbit
	 */
	public static final String ADMIN_USERNAME = "admin";

	/**
	 * Default password for administrative user in Jackrabbit
	 */
	public static final String ADMIN_PASSWORD = "admin";

	/**
	 * JCR namespace prefix for Deployit specific types and properties
	 */
	public static final String DEPLOYIT_NAMESPACE_PREFIX = "deployit";

	/**
	 * JCR namespace URI for Deployit specific types and properties
	 */
	public static final String DEPLOYIT_NAMESPACE_URI = "http://www.xebialabs.com/deployit";

	/**
	 * Prefix for JCR property names that are used to store Deployit metadata.
	 */
	public static final String METADATA_PROPERTY_NAME_PREFIX = "$";

	/**
	 * JCR node type name for {@link com.xebialabs.deployit.plugin.api.udm.ConfigurationItem configuration items}.
	 */
	public static final String CONFIGURATION_ITEM_NODETYPE_NAME = DEPLOYIT_NAMESPACE_PREFIX + ":configurationItem";

	/**
	 * JCR node type name for {@link com.xebialabs.deployit.plugin.api.udm.artifact.Artifact artifacts}.
	 */
	public static final String ARTIFACT_NODETYPE_NAME = DEPLOYIT_NAMESPACE_PREFIX + ":artifact";

	/**
	 * Name of property used to store the last modification date.
	 */
	public static final String LAST_MODIFIED_DATE_PROPERTY_NAME = METADATA_PROPERTY_NAME_PREFIX + "lastModified";

	/**
	 * Name of property used to store the {@link com.xebialabs.deployit.plugin.api.udm.ConfigurationItem#getType() configuration item type name}
	 */
	public static final String CONFIGURATION_ITEM_TYPE_PROPERTY_NAME = METADATA_PROPERTY_NAME_PREFIX + "configuration.item.type";

	/**
	 * Name of property used to store the {@link com.xebialabs.deployit.plugin.api.udm.artifact.Artifact#getFile() artifact filename}.
	 */
	public static final String FILENAME_PROPERTY_NAME = METADATA_PROPERTY_NAME_PREFIX + "filename";

	/**
	 * Name of property used to store the {@link com.xebialabs.deployit.plugin.api.udm.artifact.Artifact#getFile() artifact data}.
	 */
	public static final String DATA_PROPERTY_NAME = METADATA_PROPERTY_NAME_PREFIX + "data";

	/**
	 * JCR node type name for {@link Task tasks}.
	 */
	public static final String TASK_NODETYPE_NAME = DEPLOYIT_NAMESPACE_PREFIX + ":task";

	/**
	 * Name of JCR node under which tasks are stored.
	 */
	public static final String TASKS_NODE_NAME = "tasks";

	/**
	 * Full path of JCR node under which tasks are stored.
	 */
	public static final String TASKS_NODE_ID = "/" + TASKS_NODE_NAME;

	/**
	 * Name of property used to store the id of a task.
	 */
	public static final String TASK_ID_PROPERTY_NAME = METADATA_PROPERTY_NAME_PREFIX + "id";

	/**
	 * JCR node type name for {@link com.xebialabs.deployit.task.TaskStep steps}.
	 */
	public static final String STEP_NODETYPE_NAME = DEPLOYIT_NAMESPACE_PREFIX + ":step";

	/**
	 * Prefix used for the name of nodes that store steps.
	 */
	public static final String STEP_NODE_NAME_PREFIX = "step";

	/**
	 * JCR node type name used to store the configuration
	 */
	public static final String CONFIGURATION_NODETYPE_NAME = DEPLOYIT_NAMESPACE_PREFIX + ":configuration";

	/**
	 * Name of JCR node used to store the configuration
	 */
	public static final String CONFIGURATION_NODE_NAME = "$configuration";

	/**
	 * Full path of JCR node used to store the configuration
	 */
	public static final String CONFIGURATION_NODE_ID = "/" + CONFIGURATION_NODE_NAME;

    /**
     * Name of JCR node used to store the version information.
     */
    public static final String VERSIONS_NODE_NAME = CONFIGURATION_NODE_NAME + "/versions";

    /**
     * Full path of the JCR node used to store all version information under.
     */
    public static final String VERSIONS_NODE_ID = "/" + VERSIONS_NODE_NAME;

	/**
	 * Name of JCR node used to store security permissions under.
	 */
	public static final String SECURITY_NODE_NAME = CONFIGURATION_NODE_NAME + "/security";

	/**
	 * Full path of the JCR node used to store security permissions under.
	 */
	public static final String SECURITY_NODE_ID = "/" + SECURITY_NODE_NAME;

	/**
	 * Name of JCR node used to store security permissions under.
	 */
	public static final String ROLE_ASSIGNMENTS_NODE_NAME = CONFIGURATION_NODE_NAME + "/roleAssignments";

	/**
	 * Full path of the JCR node used to store security permissions under.
	 */
	public static final String ROLE_ASSIGNMENTS_NODE_ID = "/" + ROLE_ASSIGNMENTS_NODE_NAME;

	/**
	 * Name of JCR node used to store security permissions under.
	 */
	public static final String ROLES_NODE_NAME = CONFIGURATION_NODE_NAME + "/roles";

	/**
	 * Full path of the JCR node used to store security permissions under.
	 */
	public static final String ROLES_NODE_ID = "/" + ROLES_NODE_NAME;
}
